@@ -72,6 +72,10 @@ class MulExpression(BinaryOperator):
         tuple
             (LinOp for objective, list of constraints)
         """
+        # Promote the right hand side to a diagonal matrix if necessary.
+        if size[1] != 1 and arg_objs[1].size == (1, 1):
+            arg = lu.promote(arg_objs[1], (size[1], 1))
+            arg_objs[1] = lu.diag_vec(arg)
         return (lu.mul_expr(arg_objs[0], arg_objs[1], size), [])
 
 class DivExpression(BinaryOperator):
