@@ -20,7 +20,7 @@ along with CVXPY.  If not, see <http://www.gnu.org/licenses/>.
 import cvxpy.settings as s
 from cvxpy.atoms import *
 from cvxpy.expressions.constants import Constant, Parameter
-from cvxpy.expressions.variables import Variable
+from cvxpy.expressions.variables import Variable, semidefinite
 from cvxpy.problems.objective import *
 from cvxpy.problems.problem import Problem
 import cvxpy.interface as intf
@@ -189,19 +189,26 @@ class TestProblem(BaseTest):
         obj = 0
         def test(self):
             objective, constr_map  = self.canonicalize()
+            print len(constr_map[s.SOC])
             dims = self._format_for_solver(constr_map, s.ECOS)
             return (len(constr_map[s.EQ]),len(constr_map[s.LEQ]))
         Problem.register_solve("test", test)
         p = Problem(Minimize(obj),[eq,eq,le,le])
         result = p.solve(method="test")
-        self.assertEqual(result, (1,1))
+        self.assertEqual(result, (1, 1))
 
         # Internal constraints.
         z = hstack(self.x, self.x)
         obj = sum_entries(z[:,0] + z[:,1])
         p = Problem(Minimize(obj))
         result = p.solve(method="test")
-        self.assertEqual(result, (2,0))
+        self.assertEqual(result, (2, 0))
+
+        # Duplicates from non-linear constraints.
+        exp = norm(self.x, 2)
+        prob = Problem(Minimize(0), [exp <= 1, exp <= 2])
+        result = prob.solve(method="test")
+        self.assertEqual(result, (0, 4))
 
     # Test the is_dcp method.
     def test_is_dcp(self):
@@ -973,3 +980,25 @@ class TestProblem(BaseTest):
         result = prob.solve()
         self.assertAlmostEqual(result, -6)
         self.assertItemsAlmostEqual(expr.value, 2*c)
+
+    def test_cvxopt_errors(self):
+        """Tests that cvxopt errors are caught as solver_error.
+        """
+        # For some reason CVXOPT can't handle this problem.
+        expr = 500*self.a + square(self.a)
+        prob = Problem(Minimize(expr))
+        prob.solve(solver=s.CVXOPT)
+        self.assertEqual(prob.status, s.SOLVER_ERROR)
+
+    def test_diag_prob(self):
+        """Test a problem with diag.
+        """
+        C = Variable(3, 3)
+        obj = Maximize(C[0, 2])
+        constraints = [diag(C) == 1,
+                       C[0, 1] == 0.6,
+                       C[1, 2] == -0.3,
+                       C == semidefinite(3)]
+        prob = Problem(obj, constraints)
+        result = prob.solve()
+        self.assertAlmostEqual(result, 0.583151)
